@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
+import logging
+
 import requests
-from loguru import logger
 
 from notify.notification import Notification
 
+logger = logging.getLogger(__name__)
+
 
 class Bark(Notification):
     """Bark app 消息通知"""
